# This is the GvR version number.
# By putting it in a seperate file we don't have to import
# gvr to get a version number

VERSION = "4.4"
#last changed on 21-01-2010 --sz--

# The %s formatters are set by gvr.py
ABOUT_TEXT = """
Program:  GvRng\n
A implementation of the Guido van Robot
programming language based on Karel the Robot\n
This version is specially designed for the OLPC XO laptop.\n
Core Programmers:
    Stas Zytkiewicz - stas.zytkiewicz@gmail.com
    Waseem Daher - wdaher@mit.edu
    Steve Howell - showell@zipcon.net\n
    Paul Carduner - paulcarduner@ibiblio.org
    Donald Oellerich - trelf@ibiblio.org
    
GvRng-OLPC version: %s\n

Contributors:
    Andre Roberge - andre.roberge@gmail.com
    Michele Moore - mm@metaslash.com
    Lex Berezhny - lex@berezhny.net
    Jeff Elkner - jeff@elkner.net
    """
